@@ -2,13 +2,14 @@
 #define _ASM_TYPES_H
 
 #include <sys/types.h>
+#include <endian.h>
 
 __BEGIN_DECLS
 
 #ifdef __alpha__
-typedef unsigned int umode_t;
+typedef uint32_t umode_t;
 #else
-typedef unsigned short umode_t;
+typedef uint16_t umode_t;
 #endif
 
 typedef uint8_t __u8;
@@ -25,10 +26,10 @@ typedef int32_t __s32;
 typedef int64_t __s64;
 #endif
 
-#if defined(__alpha__)
+#if defined(__s390__) || (__WORDSIZE==64)
 typedef unsigned long __kernel_size_t;
 #else
-typedef unsigned int __kernel_size_t;
+typedef uint32_t __kernel_size_t;
 #endif
 
 #define __force
