@@ -3,8 +3,10 @@
 
 #include <sys/cdefs.h>
 
+#include <endian.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <sys/stat.h>
 
 __BEGIN_DECLS
 
@@ -77,16 +79,16 @@ __BEGIN_DECLS
 #define LOCK_RW		192	/* ... Which allows concurrent read & write ops */
 
 struct flock {
-  short l_type;
-  short l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   off_t l_start;
   off_t l_len;
   pid_t l_pid;
 };
 
 struct flock64 {
-  short  l_type;
-  short  l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   loff_t l_start;
   loff_t l_len;
   pid_t  l_pid;
@@ -156,8 +158,8 @@ struct flock64 {
 #define LOCK_RW        192     /* ... Which allows concurrent read & write ops */
 
 struct flock {
-  short l_type;
-  short l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   off_t l_start;
   off_t l_len;
   pid_t l_pid;
@@ -234,15 +236,33 @@ struct flock {
 #define LOCK_WRITE	128	/* ... Which allows concurrent write operations */
 #define LOCK_RW		192	/* ... Which allows concurrent read & write ops */
 
-typedef struct flock {
-  short l_type;
-  short l_whence;
+#ifndef __mips64__
+struct flock {
+  int16_t l_type;
+  int16_t l_whence;
   off_t l_start;
   off_t l_len;
   long  l_sysid;			/* XXXXXXXXXXXXXXXXXXXXXXXXX */
   pid_t l_pid;
   long  pad[4];			/* ZZZZZZZZZZZZZZZZZZZZZZZZZZ */
-} flock_t;
+};
+struct flock64 {
+  int16_t l_type;
+  int16_t l_whence;
+  loff_t l_start;
+  loff_t l_len;
+  pid_t l_pid;
+};
+#else
+struct flock {
+  int16_t l_type;
+  int16_t l_whence;
+  off_t l_start;
+  off_t l_len;
+  pid_t l_pid;
+};
+#define flock64 flock
+#endif
 
 #elif defined(__sparc__)
 
@@ -312,24 +332,24 @@ typedef struct flock {
 #define LOCK_RW		192	/* ... Which allows concurrent read & write ops */
 
 struct flock {
-  short l_type;
-  short l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   off_t l_start;
   off_t l_len;
   pid_t l_pid;
-  short __unused;
+  int16_t __unused;
 };
 
 #ifdef __arch64__
 #define flock64 flock
 #else
 struct flock64 {
-  short l_type;
-  short l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   loff_t l_start;
   loff_t l_len;
   pid_t l_pid;
-  short __unused;
+  int16_t __unused;
 };
 #endif
 
@@ -402,16 +422,16 @@ struct flock64 {
 #define LOCK_RW		192	/* ... Which allows concurrent read & write ops */
 
 struct flock {
-  short l_type;
-  short l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   off_t l_start;
   off_t l_len;
   pid_t l_pid;
 };
 
 struct flock64 {
-  short  l_type;
-  short  l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   loff_t l_start;
   loff_t l_len;
   pid_t  l_pid;
@@ -486,16 +506,16 @@ struct flock64 {
 #define LOCK_RW		192	/* ... Which allows concurrent read & write ops */
 
 struct flock {
-  short l_type;
-  short l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   off_t l_start;
   off_t l_len;
   pid_t l_pid;
 };
 
 struct flock64 {
-  short  l_type;
-  short  l_whence;
+  int16_t l_type;
+  int16_t l_whence;
   loff_t l_start;
   loff_t l_len;
   pid_t  l_pid;
@@ -573,8 +593,8 @@ struct flock64 {
 
 struct flock
 {
-    short int l_type;   /* Type of lock: F_RDLCK, F_WRLCK, or F_UNLCK.  */
-    short int l_whence; /* Where `l_start' is relative to (like `lseek').  */
+    int16_t l_type;   /* Type of lock: F_RDLCK, F_WRLCK, or F_UNLCK.  */
+    int16_t l_whence; /* Where `l_start' is relative to (like `lseek').  */
     off_t l_start;    /* Offset where the lock begins.  */
     off_t l_len;  /* Size of the locked area; zero means until EOF.  */
     pid_t l_pid;  /* Process holding the lock.  */
@@ -582,8 +602,8 @@ struct flock
 
 struct flock64
 {
-    short int l_type;   /* Type of lock: F_RDLCK, F_WRLCK, or F_UNLCK.  */
-    short int l_whence; /* Where `l_start' is relative to (like `lseek').  */
+    int16_t l_type;   /* Type of lock: F_RDLCK, F_WRLCK, or F_UNLCK.  */
+    int16_t l_whence; /* Where `l_start' is relative to (like `lseek').  */
     off64_t l_start;  /* Offset where the lock begins.  */
     off64_t l_len;    /* Size of the locked area; zero means until EOF.  */
     pid_t l_pid;  /* Process holding the lock.  */
@@ -592,12 +612,18 @@ struct flock64
 #endif
 
 extern int fcntl (int __fd, int __cmd, ...) __THROW;
+#ifndef __NO_STAT64
+extern int fcntl64 (int __fd, int __cmd, ...) __THROW;
+#if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
+#define fcntl fcntl64
+#endif
+#endif
 
 #if !defined(O_ASYNC) && defined(FASYNC)
 #define O_ASYNC FASYNC
 #endif
 
-#ifdef _GNU_SOURCE
+#if defined(_LINUX_SOURCE) || defined(_GNU_SOURCE)
 ssize_t readahead(int fd, off64_t *offset, size_t count);
 #endif
 
