@@ -5,7 +5,7 @@ extern int socketcall(int callno,long* args);
 
 int __libc_getsockname(int a, void * b, int c);
 int __libc_getsockname(int a, void * b, int c) {
-  unsigned long args[] = { a, (long) b, c };
+  long args[] = { a, (long) b, c };
   return socketcall(SYS_GETSOCKNAME, args);
 }
 
