@@ -5,7 +5,7 @@ extern int socketcall(int callno,long* args);
 
 int __libc_recv(int a, const void * b, size_t c, int flags);
 int __libc_recv(int a, const void * b, size_t c, int flags) {
-  unsigned long args[] = { a, (long) b, c, flags };
+  long args[] = { a, (long) b, c, flags };
   return socketcall(SYS_RECV, args);
 }
 
