@@ -5,7 +5,7 @@ extern int socketcall(int callno,long* args);
 
 int __libc_recvfrom(int a, const void * b, size_t c, int flags, void *to, void *tolen);
 int __libc_recvfrom(int a, const void * b, size_t c, int flags, void *to, void *tolen) {
-  unsigned long args[] = { a, (long) b, c, flags, (long) to, (long) tolen };
+  long args[] = { a, (long) b, c, flags, (long) to, (long) tolen };
   return socketcall(SYS_RECVFROM, args);
 }
 
