@@ -51,7 +51,9 @@ static char sccsid[] =
 /*
  * Unix longhand authenticator
  */
-static enum auth_stat _svcauth_unix(rqst, msg)
+enum auth_stat _svcauth_unix(struct svc_req* rqst, struct rpc_msg* msg);
+
+enum auth_stat _svcauth_unix(rqst, msg)
 register struct svc_req *rqst;
 register struct rpc_msg *msg;
 {
@@ -128,7 +130,9 @@ register struct rpc_msg *msg;
  * Shorthand unix authenticator
  * Looks up longhand in a cache.
  */
- /*ARGSUSED*/ static enum auth_stat _svcauth_short(rqst, msg)
+enum auth_stat _svcauth_short(struct svc_req* rqst, struct rpc_msg* msg);
+
+enum auth_stat _svcauth_short(rqst, msg)
 struct svc_req *rqst;
 struct rpc_msg *msg;
 {
